# Example Package

This is a simple example package. You can use [Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/) to write your content.

## test and build package 

```
python3 -m pip install --upgrade pip
python3 -m pip install --upgrade build
python3 -m pip install --upgrade twine
```

create pyproject.toml
```
cd ../deployments/package/

python3 -m build
```

```
```

```
```

```
```

